@@ -29,14 +29,6 @@
 //  titassist.cpp: ISO C++ implementation
 //
 
-// For username research
-#if defined(Q_OS_WIN32)
-#include <lmcons.h>
-#else
-#include <pwd.h>
-#include <unistd.h>
-#endif // #if defined(Q_OS_WIN32)
-
 // Qt style headers
 #include <qcdestyle.h>
 #include <qsgistyle.h>
@@ -57,6 +49,7 @@
 // User interface
 #include "as_gui.h"             // Main classes
 #include "as_amount.h"          // AmountBox class
+#include "as_user.h"            // User class
 
 // Icon pixel maps
 #include "as_gfx/filenew.xpm"   // static const char *s_kpcFilenew_xpm[]
@@ -90,35 +83,10 @@
 //
 void Titraqform::setupPrefs(void)
 {
-    QString Username, Homedir;
-
-// Start the show by getting the username
-#if defined(Q_OS_WIN32)
-    {
-        DWORD dwWinusernamesize = sizeof(dwWinusernamesize);
-#if defined(UNICODE)
-        TCHAR szWinusername[UNLEN + 1];   // UNLEN is defined in lmcons.h
-        GetUserName(szWinusername, &dwWinusernamesize);
-        Username = qt_winQString(szWinusername);
-#else   // Not unicode
-        char szWinusername[UNLEN + 1];    // UNLEN is defined in lmcons.h
-        GetUserNameA(szWinusername, &dwWinusernamesize);
-        Username = QString::fromLocal8Bit(szWinusername);
-    }
-#endif  // #if defined(UNICODE)
-#else   // Not windows
-    {
-//#include <stdio.h>
-//        char *szUser = NULL;
-//        szUser = cuserid();
-//        Username = QString::fromLocal8Bit(szUser);
-        char *szLogin = getlogin();
-        passwd *pUserpwd = getpwnam(szLogin);
-
-        Homedir = QString::fromLocal8Bit(pUserpwd->pw_dir);
-        Username = QString::fromLocal8Bit(szLogin);
-    }
-#endif  // #if defined(Q_OS_WIN32)
+    // Can't bootstrap until we know who is using our tool, so find out
+    User Localuser   = User();
+    QString Username = Localuser.getName();
+    QString Homedir  = Localuser.getHomedir();
 
     // Bootstrap a user preferences object from operating system info
     m_pPrefs = new Preferences(Homedir + QChar('/') +
@@ -778,8 +746,7 @@ void Titraqform::setupEditlay(void)
     m_pEditlayout->addWidget(m_pRevedit);  // Finally add the revision edit
 
     // Make the date selector
-    m_pDateedit = new QDateEdit(m_pCenframe, "Date");
-    m_pDatezero = new QDate(m_pDateedit->date());                   // Hack to store empty date
+    m_pDateedit = new Daydatedit(QDate::currentDate(), m_pCenframe, "Date");
     if (m_pDateedit == NULL)                                        // Sanity check
         throw Genexcept("Main window date edit creation failed.");  // Spew errors
 
@@ -996,8 +963,10 @@ void Titraqform::setupColumns(void)
 void Titraqform::enableIface(bool bTurned)
 {
     // FIXME: Does not belong here, so relocate
-    if (!bTurned)
+    if (!bTurned)                       // Turn off the interface
         m_pMaintable->setNumRows(0);    // Remove table data
+    else                                // Turn on the interface
+        m_pDateedit->setDayfocus();     // Default focus is on day
 
     // Enable or disable the widgets
     m_pMaintable->setEnabled(bTurned);
@@ -1036,47 +1005,36 @@ void Titraqform::enableIface(bool bTurned)
 }
 
 //
-// Check command line arguments, and parse for an existing filename
-// Returns the number of unhandled arguments, possibly multiple filenames
+// Parse command line arguments for an existing filename, and
+// open it to edit the intended (but optional) initial data
 //
-int Titraqform::setupCmdargs(void)
+void Titraqform::loadInit(void)
 {
     // If the user gives a filename argument to the shell, then open that file
     int nNumargs = qApp->argc();    // Holds the number of cmd arguments
-    int nRet = 0;                   // Holds the return value
+    int nValid = 0;                 // Holds the return value
+    QFile Initial;                  // Initial event data file
 
     if (nNumargs > 1) { // Warm up a nice cascade, to set my mind on four weeks of vacation
         for (int nIter = 1; nIter < nNumargs; nIter++) {    // Salad in New Zealand
             if (QChar(*qApp->argv()[nIter]) != '-') {       // Bunuelos in Colombia
-                this->setFilename(qApp->argv()[nIter]);     // Store inital filename
-                if (QFile::exists(*getFilename()))  
-                    return ++nRet;                          // Handled the filename
-                else
-                    ++nRet;
+                try {
+                    this->setFilename(qApp->argv()[nIter]); // Store inital filename
+                    Initial.setName(*this->getFilename());  // Initial file to load
+                    if (Initial.exists(*getFilename())) {
+                        this->loadData(Initial);            // Pass to helper method
+                        enableIface(true);                  // Turn on the lights
+                        m_pStatbar->message(trUtf8("Loaded document ") + *this->getFilename());
+                    }
+                    else // The inital file name does not correspond to a file
+                        m_pStatbar->message(trUtf8(QString("The file ") + *this->getFilename() + QString(" does not exist.")));
+                }
+                catch (Genexcept& Genex) {
+                    Genex.reportErr();
+                }
             }
         }
-        if (nRet > 0)
-            return -1;  // Return a general initial file error
     }
-    return nRet; // Return the number of unhandled arguments
-}
-
-//
-// Opens an inital event data file if one exists
-//
-void Titraqform::setupInitdata(int nFilearg)
-{
-    // Logic left over from setupCmdargs to help decide what our cmd parsing did
-    if (nFilearg == 0)                          // Args handled, no initial file
+    else
         m_pStatbar->message(trUtf8("Ready"));   // Signal a ready condition
-    else if (nFilearg > 0) {                    // Args handled, found initial file
-        QFile Initial;                          // Initial event data file to edit
-        Initial.setName(*this->getFilename());  // Initial file to load
-        this->loadData(Initial);                // Pass to helper method
-        enableIface(true);                      // Turn on the lights
-        m_pStatbar->message(trUtf8("Loaded document ") + *this->getFilename());
-    }
-    else   // The inital file name does not correspond to a file
-        m_pStatbar->message(trUtf8(QString("The file ") + *this->getFilename() + QString(" does not exist.")));
-
 }
