@@ -35,7 +35,6 @@
 #include <qclipboard.h>
 #include <qmenudata.h>
 #include <qdatastream.h>
-//#include <qregexp.h>
 
 // User interface
 #include "as_gui.h"             // Main classes
@@ -43,6 +42,7 @@
 #include "as_tableitem.h"       // For our custom table items
 #include "as_generic.h"         // Generic classes
 #include "as_uuid.h"            // UUID classes
+#include "as_datedit.h"         // Derived from QDateEdit
 
 // RPC headers
 #ifdef HAVE_ESOAP
@@ -303,9 +303,8 @@ void Titraqform::newDoc(void)
     m_pMaintable->setNumRows(0);        // Remove all data in table
     this->setCaption(trUtf8("No file name"));
     m_pStatbar->message(trUtf8("New document"), 4000);
-    this->setFilename("");
+    this->setFilename(QString(""));
     this->addEntry(1);                  // Default new op adds a row
-    this->updEdit(1);                   // Update edit controls
     m_pMaintable->setDirty(false);      // Start out clean
 }
 
@@ -341,6 +340,7 @@ void Titraqform::openDoc(void)
                 }
                 catch (Genexcept& Genex) {
                     Genex.reportErr();
+                    return;
                 }
                 break;
             case 1: // Don't save first but do load
@@ -351,6 +351,7 @@ void Titraqform::openDoc(void)
                 }
                 catch (Genexcept& Genex) {
                     Genex.reportErr();
+                    return;
                 }
                 break;
             case 2: // Don't do a load timesheet
@@ -366,6 +367,7 @@ void Titraqform::openDoc(void)
             }
             catch (Genexcept& Genex) {
                 Genex.reportErr();
+                return;
             }
         }
 
@@ -388,12 +390,18 @@ void Titraqform::saveFile(void)
     QTextStream Streamevents, Streambak;
 
     try {
-        Fname = QString(*this->getFilename());
+        Fname = *this->getFilename();
 
-        // First time saves are really just saveAs in disguise
+        // First time saves are really just saveName in disguise
         if (Fname.isEmpty()) {
-            this->saveAs();
-            return;
+            try {
+                this->saveName();       // Try to 'save as'
+                return;                 // and short circuit
+            }
+            catch (Genexcept& Genex) {
+                Genex.reportErr();      // Report the error
+                return;                 // and short circuit
+            }
         }
 
         Filevents.setName(Fname); // Construct a file to back up and write
@@ -457,9 +465,55 @@ void Titraqform::saveAs(void)
             this->saveFile();               // Finish by calling the save action
         }
     }
-    else {
+    else
         // User did not select a valid file and push okay button
         m_pStatbar->message(trUtf8("Saving aborted"), 4000);
+}
+
+//
+// Implicitly serialize current state to a selected file
+// The main difference with saveAs is that this uses exceptions
+//
+void Titraqform::saveName(void)
+{
+    int nResult = 0; // For checking user's answer
+
+    // Make sure we correctly get the name of the default file to open
+    QString Openas = m_pPrefs->getString(TITRAQ_PREFASFILE, TITRAQ_DEFASFILE);
+    if (Openas.startsWith(TITRAQ_HOMEDIRTOK))
+        Openas = QDir::homeDirPath() + Openas.remove(0, QString(TITRAQ_HOMEDIRTOK).length() - 1);
+
+    nResult = 1;            // We loop on this dialog only if an indecisive user
+    while (nResult > 0) {   // is hesitant to overwrite a file over and over again
+        QString Filestring = QFileDialog::getSaveFileName(Openas, trUtf8("Accounting Data (*.as);;Text files (*.txt);;All Files (*)"), this, trUtf8("ChooserDialog"), trUtf8("Choose a file to save"), NULL, false);
+        if (!Filestring.isEmpty()) {
+            if (QFile::exists(Filestring)) {
+                nResult = QMessageBox::warning(this, trUtf8(TITRAQ_APPTITLE),
+                          trUtf8(TITRAQ_OVERWRITE), trUtf8("&Yes"), trUtf8("&No"), NULL, 1, 1);
+                switch (nResult) {
+                case 0: // Overwrite contents
+                    this->setFilename(Filestring);
+                    this->saveFile();
+                    break;
+                case 1: // Don't overwrite
+                default:
+                    break;
+                }
+            }
+            else {
+                QString Extension = TITRAQ_FEXTENSION;  // Logic to handle
+                if (!Filestring.endsWith(Extension))    // AS file extension
+                    Filestring += Extension;            // insertion
+                this->setFilename(Filestring);  // Set filename of object first
+                nResult = 0;                    // Reset our loop control
+                this->saveFile();               // Finish by calling the save action
+            }
+        }
+        else {
+            // User did not select a valid file and push okay button
+            m_pStatbar->message(trUtf8("Saving aborted"), 4000);
+            throw Genexcept(TITRAQ_SAVECANCELLED);
+        }
     }
 }
 
@@ -494,9 +548,17 @@ void Titraqform::closeEvent(QCloseEvent *pClosit)
     }
 
     // Fall through to implicit close code
-    this->enableIface(false);   // Turn off the lights
-    this->setOpen(false);       // Set doc state to closed
-    pClosit->ignore();          // Finish off by not closing
+    this->setCaption(TITRAQ_APPTITLE);
+    try { // There might be problems, so wrap these last ops with error handling
+        if (this->isOpen())
+            m_pStatbar->message(trUtf8("Closed document ") + *this->getFilename(), 4000);
+        this->setOpen(false);       // Set doc state to closed
+        this->enableIface(false);   // Turn off the lights
+    }
+    catch (Genexcept& Genex) {
+        Genex.reportErr();
+    }
+    pClosit->ignore();              // Finish off by not closing
 }
 
 //
@@ -732,7 +794,7 @@ void Titraqform::updEdit(int nRow, int nCol)
     if (!Textdate.isEmpty())
         m_pDateedit->setDate(QDate::fromString(Textdate, Qt::ISODate));
     else
-        m_pDateedit->setDate(*m_pDatezero);
+        m_pDateedit->setDate(QDate::currentDate());
     if (!Textstart.isEmpty())
         m_pStarttime->setTime(QTime::fromString(Textstart, Qt::ISODate));
     else
@@ -841,9 +903,6 @@ void Titraqform::updateRev(const QString &Instring)
 //
 void Titraqform::updateDate(const QDate &Dateup)
 {
-    if (Dateup == *m_pDatezero) // Complete the already nasty hack
-        m_pMaintable->setText(m_pMaintable->currentRow(), TITRAQ_IDXDATE, trUtf8(TITRAQ_DATEZERO));
-    else
         m_pMaintable->setText(m_pMaintable->currentRow(), TITRAQ_IDXDATE, Dateup.toString("yyyy.MM.dd"));
 }
 
